import { type Context, type Handler } from "aws-lambda";

import config from "./config";

import { handler as chilecultura } from "./portales/chilecultura/handler";
import { handler as df } from "./portales/df/handler";
import { handler as elciudadano } from "./portales/elciudadano/handler";
import { handler as eldesconcierto } from "./portales/eldesconcierto/handler";
import { handler as elmostrador } from "./portales/elmostrador/handler";
import { handler as emol } from "./portales/emol/handler";
import { handler as interferencia } from "./portales/interferencia/handler";
import { handler as latercera } from "./portales/latercera/handler";
// import { handler as metrodesantiago } from "./portales/metrodesantiago/handler";
import { handler as theclinic } from "./portales/theclinic/handler";

const context: Context = {
  callbackWaitsForEmptyEventLoop: false,
  functionName: "",
  functionVersion: "",
  invokedFunctionArn: "",
  memoryLimitInMB: "0",
  awsRequestId: "",
  logGroupName: "",
  logStreamName: "",
  done: () => {},
  fail: () => {},
  succeed: () => {},
  getRemainingTimeInMillis: () => 1
};

const portalsHandlers = {
  "chilecultura": chilecultura,
  "df": df,
  "elciudadano": elciudadano,
  "eldesconcierto": eldesconcierto,
  "elmostrador": elmostrador,
  "emol": emol,
  "interferencia": interferencia,
  "latercera": latercera,
  // "metrodesantiago": metrodesantiago,
  "theclinic": theclinic,
};

const activePortalsHandlers: Array<Handler> = Object.keys(portalsHandlers)
  .filter((portalName) => ! config.DEVELOP || config.DEV_ACTIVE_PORTALS.includes(portalName))
  .map((portalName) => portalsHandlers[portalName]);

const cooldown = 10000; // 10 seconds
async function main (): Promise<void> {
  for (const portalHandler of activePortalsHandlers) {
    await portalHandler(null, context, () => {});
    await new Promise((resolve) => setTimeout(resolve, cooldown));
  }
}

main()
  .catch((err) => {
    console.error(err)
  })
  .finally(() => {
    process.exit(0);
  });
